pub struct HexBytesOptions {
pub truncate_above: Option<usize>,
pub head: usize,
pub tail: usize,
}Expand description
Options for hex byte serialization.
Fields
truncate_above: Option<usize>Truncate when the byte length exceeds this threshold.
None means never truncate.
head: usizeNumber of bytes to keep from the start when truncating.
tail: usizeNumber of bytes to keep from the end when truncating.
Implementations