HexBytesOptions

Struct HexBytesOptions 

pub struct HexBytesOptions {
    pub truncate_above: Option<usize>,
    pub head: usize,
    pub tail: usize,
}
Options for hex byte serialization.

Fields

truncate_above: Option<usize>

Truncate when the byte length exceeds this threshold.

None means never truncate.

head: usize

Number of bytes to keep from the start when truncating.

tail: usize

Number of bytes to keep from the end when truncating.

Implementations

Source

impl HexBytesOptions

pub const fn new() -> Self

Create default hex byte options (no truncation).

pub const fn truncate(self, truncate_above: usize) -> Self

Truncate when byte length exceeds truncate_above.

pub const fn head_tail(self, head: usize, tail: usize) -> Self

Set the number of head/tail bytes to keep when truncating.